@@ -44,7 +44,7 @@ void parseReleaseLimit(Config& config, const string& limitName, const string& in
 	auto limitOptionName = string("cupt::cache::limit-releases::by-") + limitName;
 	if (!included.empty() && !excluded.empty())
 	{
-		fatal2("options '--include-%ss' and '--exclude-%ss' cannot be specified together",
+		fatal2(__("options '--include-%ss' and '--exclude-%ss' cannot be specified together"),
 				limitName, limitName);
 	}
 	else if (!included.empty())
@@ -130,7 +130,7 @@ string parseCommonOptions(int argc, char** argv, Config& config, vector< string
 		{ // processing
 			if (command.empty())
 			{
-				fatal2("no command specified");
+				fatal2(__("no command specified"));
 			}
 			if (variablesMap.count("important"))
 			{
@@ -166,13 +166,12 @@ string parseCommonOptions(int argc, char** argv, Config& config, vector< string
 		}
 
 		smatch m;
-		FORIT(directOptionIt, directOptions)
+		for (const string& directOption: directOptions)
 		{
 			static const sregex optionRegex = sregex::compile("(.*?)=(.*)");
-			const string& directOption = *directOptionIt;
 			if (!regex_match(directOption, m, optionRegex))
 			{
-				fatal2("invalid option syntax in '%s' (right is '<option>=<value>')", directOption);
+				fatal2(__("invalid option syntax in '%s' (right is '<option>=<value>')"), directOption);
 			}
 			string key = m[1];
 			string value = m[2];
@@ -192,11 +191,11 @@ string parseCommonOptions(int argc, char** argv, Config& config, vector< string
 	}
 	catch (const bpo::error& e)
 	{
-		fatal2("failed to parse command-line options: %s", e.what());
+		fatal2(__("failed to parse command-line options: %s"), e.what());
 	}
 	catch (Exception&)
 	{
-		fatal2("error while processing command-line options");
+		fatal2(__("error while processing command-line options"));
 	}
 	return command;
 }
@@ -225,11 +224,11 @@ bpo::variables_map parseOptions(const Context& context, bpo::options_description
 	}
 	catch (const bpo::unknown_option& e)
 	{
-		fatal2("unknown option '%s'", e.get_option_name());
+		fatal2(__("unknown option '%s'"), e.get_option_name());
 	}
 	catch (const bpo::error& e)
 	{
-		fatal2("failed to parse options: %s", e.what());
+		fatal2(__("failed to parse command-line options: %s"), e.what());
 	}
 	bpo::notify(variablesMap);
 
@@ -276,7 +275,7 @@ std::function< int (Context&) > getHandler(const string& command)
 	auto it = handlerMap.find(command);
 	if (it == handlerMap.end())
 	{
-		fatal2("unrecognized command '%s'", command);
+		fatal2(__("unrecognized command '%s'"), command);
 	}
 	return it->second;
 }
@@ -286,7 +285,7 @@ void checkNoExtraArguments(const vector< string >& arguments)
 	if (!arguments.empty())
 	{
 		auto argumentsString = join(" ", arguments);
-		warn2("extra arguments '%s' are not processed", argumentsString);
+		warn2(__("extra arguments '%s' are not processed"), argumentsString);
 	}
 }
 
@@ -296,7 +295,7 @@ void handleQuietOption(const Config& config)
 	{
 		if (!freopen("/dev/null", "w", stdout))
 		{
-			fatal2e("unable to redirect standard output to '/dev/null'");
+			fatal2e(__("unable to redirect standard output to '/dev/null'"));
 		}
 	}
 }
@@ -316,7 +315,7 @@ shared_ptr< Config > Context::getConfig()
 		}
 		catch (Exception&)
 		{
-			fatal2("error while loading config");
+			fatal2(__("error while loading the configuration"));
 		}
 	}
 	return __config;
@@ -344,7 +343,7 @@ shared_ptr< const Cache > Context::getCache(
 		}
 		catch (Exception&)
 		{
-			fatal2("error while creating package cache");
+			fatal2(__("error while creating the package cache"));
 		}
 	}
 
