@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2010 by Eugene V. Lyubimkin                             *
+*   Copyright (C) 2010-2012 by Eugene V. Lyubimkin                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License                  *
@@ -40,7 +40,7 @@ class CurlWrapper
 		__handle = curl_easy_init();
 		if (!__handle)
 		{
-			fatal("unable to create Curl handle");
+			fatal2(__("unable to create a Curl handle"));
 		}
 		__init();
 	}
@@ -49,7 +49,7 @@ class CurlWrapper
 		auto returnCode = curl_easy_setopt(__handle, optionName, value);
 		if (returnCode != CURLE_OK)
 		{
-			fatal("unable to set long Curl option '%s': curl_easy_setopt failed: %s",
+			fatal2(__("unable to set the Curl option '%s': curl_easy_setopt failed: %s"),
 					alias, curl_easy_strerror(returnCode));
 		}
 	}
@@ -58,7 +58,7 @@ class CurlWrapper
 		auto returnCode = curl_easy_setopt(__handle, optionName, value);
 		if (returnCode != CURLE_OK)
 		{
-			fatal("unable to set object Curl option '%s': curl_easy_setopt failed: %s",
+			fatal2(__("unable to set the Curl option '%s': curl_easy_setopt failed: %s"),
 					alias, curl_easy_strerror(returnCode));
 		}
 	}
@@ -67,7 +67,7 @@ class CurlWrapper
 		auto returnCode = curl_easy_setopt(__handle, optionName, value.c_str());
 		if (returnCode != CURLE_OK)
 		{
-			fatal("unable to set string Curl option '%s': curl_easy_setopt failed: %s",
+			fatal2(__("unable to set the Curl option '%s': curl_easy_setopt failed: %s"),
 					alias, curl_easy_strerror(returnCode));
 		}
 	}
@@ -76,7 +76,7 @@ class CurlWrapper
 		auto returnCode = curl_easy_setopt(__handle, optionName, value);
 		if (returnCode != CURLE_OK)
 		{
-			fatal("unable to set large Curl option '%s': curl_easy_setopt failed: %s",
+			fatal2(__("unable to set the Curl option '%s': curl_easy_setopt failed: %s"),
 					alias, curl_easy_strerror(returnCode));
 		}
 	}
@@ -84,6 +84,7 @@ class CurlWrapper
 	{
 		setOption(CURLOPT_FAILONERROR, 1, "fail on error");
 		setOption(CURLOPT_NETRC, CURL_NETRC_OPTIONAL, "netrc");
+		setOption(CURLOPT_USERAGENT, format2("Curl (libcupt/%s)", cupt::libraryVersion), "user-agent");
 		curl_easy_setopt(__handle, CURLOPT_ERRORBUFFER, __error_buffer);
 	}
 	ssize_t getExpectedDownloadSize() const
@@ -200,7 +201,7 @@ class CurlMethod: public cupt::download::Method
 			File file(targetPath, "a", openError);
 			if (!openError.empty())
 			{
-				fatal("unable to open file '%s': %s", targetPath.c_str(), openError.c_str());
+				fatal2(__("unable to open the file '%s': %s"), targetPath, openError);
 			}
 
 			start:
@@ -243,7 +244,7 @@ class CurlMethod: public cupt::download::Method
 				{
 					if (config->getBool("debug::downloader"))
 					{
-						debug("transient error while downloading '%s'", string(uri).c_str());
+						debug2("transient error while downloading '%s'", string(uri));
 					}
 					--transientErrorsLeft;
 					goto start;
@@ -253,12 +254,11 @@ class CurlMethod: public cupt::download::Method
 				{
 					if (config->getBool("debug::downloader"))
 					{
-						debug("range command failed, need to restart from beginning while downloading '%s'",
-								string(uri).c_str());
+						debug2("range command failed, need to restart from beginning while downloading '%s'", string(uri));
 					}
 					if (unlink(targetPath.c_str()) == -1)
 					{
-						return sf(__("unable to delete target file for re-downloading: EEE"));
+						return format2e(__("unable to remove target file for re-downloading"));
 					}
 					goto start;
 				}
@@ -268,7 +268,7 @@ class CurlMethod: public cupt::download::Method
 		}
 		catch (Exception& e)
 		{
-			return sf(__("download method error: %s"), e.what());
+			return format2(__("download method error: %s"), e.what());
 		}
 	}
 };
