@@ -156,21 +156,24 @@ shared_ptr< const SourcePackage > Cache::getSourcePackage(const string& packageN
 
 ssize_t Cache::getPin(const shared_ptr< const Version >& version) const
 {
-	string installedVersionString;
-	if (dynamic_pointer_cast< const BinaryVersion >(version))
+	auto getInstalledVersionString = [this, &version]()
 	{
-		auto package = getBinaryPackage(version->packageName);
-		if (package)
+		if (dynamic_pointer_cast< const BinaryVersion >(version))
 		{
-			auto installedVersion = package->getInstalledVersion();
-			if (installedVersion)
+			auto package = getBinaryPackage(version->packageName);
+			if (package)
 			{
-				installedVersionString = installedVersion->versionString;
+				auto installedVersion = package->getInstalledVersion();
+				if (installedVersion)
+				{
+					return installedVersion->versionString;
+				}
 			}
 		}
-	}
+		return string();
+	};
 
-	return __impl->getPin(version, installedVersionString);
+	return __impl->getPin(version, getInstalledVersionString);
 }
 
 vector< Cache::PinnedVersion > Cache::getSortedPinnedVersions(const shared_ptr< const Package >& package) const
@@ -180,18 +183,27 @@ vector< Cache::PinnedVersion > Cache::getSortedPinnedVersions(const shared_ptr<
 	auto versions = package->getVersions();
 
 	string installedVersionString;
-	if (auto binaryPackage = dynamic_pointer_cast< const BinaryPackage >(package))
+	bool ivsIsSet = false;
+	auto getInstalledVersionString = [&installedVersionString, &ivsIsSet, &package]()
 	{
-		auto installedVersion = binaryPackage->getInstalledVersion();
-		if (installedVersion)
+		if (!ivsIsSet)
 		{
-			installedVersionString = installedVersion->versionString;
+			if (auto binaryPackage = dynamic_pointer_cast< const BinaryPackage >(package))
+			{
+				auto installedVersion = binaryPackage->getInstalledVersion();
+				if (installedVersion)
+				{
+					installedVersionString = installedVersion->versionString;
+				}
+			}
+			ivsIsSet = true;
 		}
-	}
+		return installedVersionString;
+	};
 
 	for (const auto& version: versions)
 	{
-		result.push_back(PinnedVersion(version, __impl->getPin(version, installedVersionString)));
+		result.push_back(PinnedVersion(version, __impl->getPin(version, getInstalledVersionString)));
 	}
 
 	auto sorter = [](const PinnedVersion& left, const PinnedVersion& right) -> bool
@@ -250,22 +262,21 @@ vector< shared_ptr< const BinaryVersion > > Cache::getInstalledVersions() const
 	vector< shared_ptr< const BinaryVersion > > result;
 
 	auto packageNames = __impl->systemState->getInstalledPackageNames();
-	FORIT(packageNameIt, packageNames)
+	result.reserve(packageNames.size());
+	for (const string& packageName: packageNames)
 	{
-		const string& packageName = *packageNameIt;
-
 		auto package = getBinaryPackage(packageName);
 		if (!package)
 		{
-			fatal2("internal error: unable to find the package '%s'", packageName);
+			fatal2i("unable to find the package '%s'", packageName);
 		}
 		auto version = package->getInstalledVersion();
 		if (!version)
 		{
-			fatal2("internal error: the package '%s' does not have installed version", packageName);
+			fatal2i("the package '%s' does not have installed version", packageName);
 		}
 
-		result.push_back(version);
+		result.push_back(std::move(version));
 	}
 
 	return result;
@@ -284,7 +295,7 @@ pair< string, string > Cache::getLocalizedDescriptions(const shared_ptr< const B
 // static
 bool Cache::verifySignature(const shared_ptr< const Config >& config, const string& path)
 {
-	return internal::cachefiles::verifySignature(*config, path);
+	return internal::cachefiles::verifySignature(*config, path, path);
 }
 
 string Cache::getPathOfCopyright(const shared_ptr< const BinaryVersion >& version)
