@@ -42,7 +42,7 @@ bool checkPackageName(const string& input, bool throwOnError)
 	bool result = (resultEnd == input.end());
 	if (!result && throwOnError)
 	{
-		fatal2("invalid package name '%s'", input);
+		fatal2(__("invalid package name '%s'"), input);
 	}
 	return result;
 }
@@ -134,17 +134,17 @@ bool checkVersionString(const string& input, bool throwOnError)
 	bool result = __check_version_string(input, underscoresPresent, firstUpstreamCharacter);
 	if (!result && throwOnError)
 	{
-		fatal2("invalid version string '%s'", input);
+		fatal2(__("invalid version string '%s'"), input);
 	}
 	if (result)
 	{
 		if (underscoresPresent)
 		{
-			warn2("version string '%s': should not contain underscores", input);
+			warn2(__("version string '%s': should not contain underscores"), input);
 		}
 		if (firstUpstreamCharacter < '0' || firstUpstreamCharacter > '9')
 		{
-			warn2("version string '%s': first upstream character '%c' is not a digit",
+			warn2(__("version string '%s': first upstream character '%c' is not a digit"),
 					input, firstUpstreamCharacter);
 		}
 	}
