@@ -49,6 +49,12 @@ using namespace cupt::download;
 
 typedef Manager::ExtendedUri ExtendedUri;
 
+struct InputMessage
+{
+	int sock;
+	vector< string > message;
+};
+
 using std::queue;
 using std::map;
 using std::multimap;
@@ -56,19 +62,21 @@ using std::set;
 using boost::lexical_cast;
 using std::make_pair;
 
+typedef queue< vector< string > > MessageQueue;
+
 static void sendSocketMessage(int socket, const vector< string >& message)
 {
 	auto compactedMessage = join("\1", message);
 	if (message.size() >= 0xFFFF)
 	{
-		fatal2("internal error: sendSocketMessage: message size exceeded 64K");
+		fatal2i("sendSocketMessage: message size exceeded 64K");
 	}
 	uint16_t len = compactedMessage.size();
 
 	if (write(socket, &len, sizeof(len)) == -1 ||
 			write(socket, compactedMessage.c_str(), len) == -1)
 	{
-		fatal2e("unable to send socket message");
+		fatal2e(__("unable to send a socket message"));
 	}
 }
 
@@ -79,52 +87,44 @@ static void sendSocketMessage(Pipe& pipe, const vector< string >& message)
 
 static vector< string > receiveSocketMessage(int socket)
 {
-	string compactedMessage;
-
 	uint16_t len;
 	auto readResult = read(socket, &len, sizeof(len));
 	if (readResult == -1)
 	{
 		if (errno != ECONNRESET /* handled under */)
 		{
-			fatal2e("unable to receive socket message length");
+			fatal2e(__("unable to receive a socket message length"));
 		}
 	}
 	else if (readResult != sizeof(len) && readResult != 0)
 	{
-		fatal2("unable to receive socket message length: partial message arrived");
+		fatal2(__("unable to receive a socket message length: %s"), __("partial message arrived"));
 	}
 
 	if (readResult == 0 || readResult == -1 /* connection reset */)
 	{
-		compactedMessage = "eof";
+		return { "eof" };
 	}
 	else
 	{
-		char* buf = new char[len];
+		char buf[0xFFFF]; // must be enough for reading max(uint16) bytes
 		readResult = read(socket, buf, len);
-		compactedMessage.assign(buf, len);
-		delete[] buf;
 		if (readResult == -1)
 		{
-			fatal2e("unable to receive socket message");
+			fatal2e(__("unable to receive a socket message"));
 		}
 		else if (readResult == 0)
 		{
-			fatal2("unable to receive socket message: unexpected end of stream");
+			fatal2(__("unable to receive a socket message: %s"), __("unexpected end of stream"));
 		}
 		else if (readResult != len)
 		{
-			fatal2("unable to receive socket message: partial message arrived");
+			fatal2(__("unable to receive a socket message: %s"), __("partial message arrived"));
 		}
-	}
 
-	auto result = split('\1', compactedMessage, true);
-	if (result.empty())
-	{
-		fatal2("received an empty message from socket");
+		string compactedMessage(buf, len);
+		return split('\1', compactedMessage, true);
 	}
-	return result;
 }
 
 struct InnerDownloadElement
@@ -166,15 +166,16 @@ class ManagerImpl
 	map< string, size_t > sizes;
 
 	void finishPendingDownload(multimap< string, int >::iterator, const string&, bool);
-	void processFinalResult(Pipe& workerPipe, const vector< string >& params, bool debugging);
-	void processPreliminaryResult(Pipe& workerPipe, const vector< string >& params, bool debugging);
-	void processProgressMessage(Pipe& workerPipe, const vector< string >& params);
-	void proceedDownload(Pipe& workerPipe, const vector< string >& params, bool debugging);
-	void killPerformerBecauseOfWrongSize(Pipe& workerPipe, const string& uri,
+	void processFinalResult(MessageQueue&, const vector< string >& params, bool debugging);
+	void processPreliminaryResult(MessageQueue&, const vector< string >& params, bool debugging);
+	void processProgressMessage(MessageQueue&, const vector< string >& params);
+	void proceedDownload(MessageQueue&, const vector< string >& params, bool debugging);
+	void killPerformerBecauseOfWrongSize(MessageQueue&, const string& uri,
 			const string& actionName, const string& errorString);
 	void terminateDownloadProcesses();
 	void startNewDownload(const string& uri, const string& targetPath, int waiterSocket, bool debugging);
-	int pollAllSockets(const vector< int >& persistentSockets, set< int >& clientSockets,
+	InputMessage pollAllInput(MessageQueue& workerQueue,
+			const vector< int >& persistentSockets, set< int >& clientSockets,
 			bool exitFlag, bool debugging);
 	void worker();
 	string perform(const string& uri, const string& targetPath, int sock);
@@ -213,17 +214,17 @@ ManagerImpl::ManagerImpl(const shared_ptr< const Config >& config_, const shared
 	serverSocket = socket(AF_UNIX, SOCK_STREAM, 0);
 	if (serverSocket == -1)
 	{
-		fatal2e("unable to open server socket");
+		fatal2e(__("unable to open the server socket"));
 	}
 	serverSocketAddress.sun_family = AF_UNIX;
 	strcpy(serverSocketAddress.sun_path, serverSocketPath.c_str());
 	if (bind(serverSocket, (sockaddr*)&serverSocketAddress, sizeof(sockaddr_un)) == -1)
 	{
-		fatal2e("unable to bind server socket to file '%s'", serverSocketPath);
+		fatal2e(__("unable to bind the server socket to the file '%s'"), serverSocketPath);
 	}
 	if (listen(serverSocket, SOMAXCONN) == -1)
 	{
-		fatal2e("unable to make server socket on file '%s' listen for connections", serverSocketPath);
+		fatal2e(__("unable to make the server socket on the file '%s' listen for connections"), serverSocketPath);
 	}
 
 	parentPipe.reset(new Pipe("parent"));
@@ -231,7 +232,7 @@ ManagerImpl::ManagerImpl(const shared_ptr< const Config >& config_, const shared
 	auto pid = fork();
 	if (pid == -1)
 	{
-		fatal2e("unable to create download worker process: fork failed");
+		fatal2e(__("unable to create the download worker process: fork() failed"));
 	}
 
 	if (pid)
@@ -255,7 +256,7 @@ ManagerImpl::ManagerImpl(const shared_ptr< const Config >& config_, const shared
 
 			if (config->getBool("debug::downloader"))
 			{
-				debug2("aborting download worker process because of exception");
+				debug2("aborting the download worker process because of the exception");
 			}
 
 			terminateDownloadProcesses();
@@ -277,28 +278,28 @@ ManagerImpl::~ManagerImpl()
 			int childExitStatus;
 			if (waitpid(workerPid, &childExitStatus, 0) == -1)
 			{
-				warn2e("unable to shutdown download worker process: waitpid failed");
+				warn2e(__("unable to shutdown the download worker process: waitpid() failed"));
 			}
 			else if (childExitStatus != 0)
 			{
-				warn2("download worker process exited abnormally: %s",
+				warn2(__("the download worker process exited abnormally: %s"),
 						getWaitStatusDescription(childExitStatus));
 			}
 		}
 		else
 		{
-			warn2("download worker process aborted unexpectedly");
+			warn2(__("the download worker process aborted unexpectedly"));
 		}
 
 		// cleaning server socket
 		if (close(serverSocket) == -1)
 		{
-			warn2e("unable to close download server socket");
+			warn2e(__("unable to close the download server socket"));
 		}
 
 		if (unlink(serverSocketPath.c_str()) == -1)
 		{
-			warn2e("unable to delete download server socket file '%s'", serverSocketPath);
+			warn2e(__("unable to remove the download server socket file '%s'"), serverSocketPath);
 		}
 	}
 }
@@ -312,7 +313,7 @@ void ManagerImpl::terminateDownloadProcesses()
 		{
 			if (errno != ESRCH)
 			{
-				warn2("download manager: unable to terminate a performer process (pid '%d')", pid);
+				warn2(__("download manager: unable to terminate a performer process (pid '%d')"), pid);
 			}
 		}
 	}
@@ -333,18 +334,16 @@ void sendPingMessage(int)
 
 void enablePingTimer()
 {
-	// so, to avoid potential clash with simultaneously writing to workerPipe in a signal
-	// and in the processing thread, create another pipe
 	struct sigaction newAction;
 	newAction.sa_handler = sendPingMessage;
 	if (sigfillset(&newAction.sa_mask) == -1)
 	{
-		fatal2e("sigfillset failed");
+		fatal2e(__("%s() failed"), "sigfillset");
 	}
 	newAction.sa_flags = SA_RESTART;
 	if (sigaction(SIGALRM, &newAction, NULL) == -1)
 	{
-		fatal2e("unable to set up ALRM signal handler: sigaction failed");
+		fatal2e(__("%s() failed"), "sigaction");
 	}
 
 	struct itimerval timerStruct;
@@ -354,7 +353,7 @@ void enablePingTimer()
 	timerStruct.it_value.tv_usec = timerStruct.it_interval.tv_usec;
 	if (setitimer(ITIMER_REAL, &timerStruct, NULL) == -1)
 	{
-		fatal2e("unable to enable ALRM signal: setitimer failed");
+		fatal2e(__("%s() failed"), "setitimer");
 	}
 }
 
@@ -364,12 +363,12 @@ void disablePingTimer()
 	defaultAction.sa_handler = SIG_DFL;
 	if (sigemptyset(&defaultAction.sa_mask) == -1)
 	{
-		fatal2e("sigemptyset failed");
+		fatal2e(__("%s() failed"), "sigemptyset");
 	}
 	defaultAction.sa_flags = 0;
 	if (sigaction(SIGALRM, &defaultAction, NULL) == -1)
 	{
-		fatal2e("unable to clear ALRM signal handler: sigaction failed");
+		fatal2e(__("%s() failed"), "sigaction");
 	}
 
 	struct itimerval timerStruct;
@@ -379,16 +378,16 @@ void disablePingTimer()
 	timerStruct.it_value.tv_usec = 0;
 	if (setitimer(ITIMER_REAL, &timerStruct, NULL) == -1)
 	{
-		fatal2e("unable to disable ALRM signal: setitimer failed");
+		fatal2e(__("%s() failed"), "setitimer");
 	}
 }
 
-void ManagerImpl::processPreliminaryResult(Pipe& workerPipe,
+void ManagerImpl::processPreliminaryResult(MessageQueue& workerQueue,
 		const vector< string >& params, bool debugging)
 {
 	if (params.size() != 2) // uri, result
 	{
-		fatal2("internal error: download manager: wrong parameter count for 'done' message");
+		fatal2i("download manager: wrong parameter count for 'done' message");
 	}
 	const string& uri = params[0];
 	const string& result = params[1];
@@ -402,7 +401,7 @@ void ManagerImpl::processPreliminaryResult(Pipe& workerPipe,
 	auto downloadInfoIt = activeDownloads.find(uri);
 	if (downloadInfoIt == activeDownloads.end())
 	{
-		fatal2("internal error: download manager: received preliminary result for unexistent download, uri '%s'", uri);
+		fatal2i("download manager: received preliminary result for unexistent download, uri '%s'", uri);
 	}
 	ActiveDownloadInfo& downloadInfo = downloadInfoIt->second;
 	sendSocketMessage(downloadInfo.waiterSocket,
@@ -411,12 +410,12 @@ void ManagerImpl::processPreliminaryResult(Pipe& workerPipe,
 	// cleanup after child
 	if (waitpid(downloadInfo.performerPid, NULL, 0) == -1)
 	{
-		fatal2e("waitpid on performer process failed");
+		fatal2e(__("waitpid on the performer process failed"));
 	}
 	downloadInfo.performerPipe.reset();
 
 	// update progress
-	sendSocketMessage(workerPipe, vector< string >{ "progress", uri, "pre-done" });
+	workerQueue.push({ "progress", uri, "pre-done" });
 }
 
 void ManagerImpl::finishPendingDownload(multimap< string, int >::iterator pendingDownloadIt,
@@ -428,7 +427,7 @@ void ManagerImpl::finishPendingDownload(multimap< string, int >::iterator pendin
 
 	if (debugging)
 	{
-		debug2("final download result for duplicated request: '%s': %s", uri, result);
+		debug2("final download result for a duplicated request: '%s': %s", uri, result);
 	}
 	auto waiterSocket = pendingDownloadIt->second;
 	sendSocketMessage(waiterSocket,
@@ -437,12 +436,12 @@ void ManagerImpl::finishPendingDownload(multimap< string, int >::iterator pendin
 	pendingDuplicates.erase(pendingDownloadIt);
 }
 
-void ManagerImpl::processFinalResult(Pipe& workerPipe,
+void ManagerImpl::processFinalResult(MessageQueue& workerQueue,
 		const vector< string >& params, bool debugging)
 {
 	if (params.size() != 2) // uri, result
 	{
-		fatal2("internal error: download manager: wrong parameter count for 'done-ack' message");
+		fatal2i("download manager: wrong parameter count for 'done-ack' message");
 	}
 
 	const string& uri = params[0];
@@ -476,48 +475,48 @@ void ManagerImpl::processFinalResult(Pipe& workerPipe,
 	auto downloadInfoIt = activeDownloads.find(uri);
 	if (downloadInfoIt == activeDownloads.end())
 	{
-		fatal2("internal error: download manager: received final result for unexistent download, uri '%s'", uri);
+		fatal2i("download manager: received final result for unexistent download, uri '%s'", uri);
 	}
 	activeDownloads.erase(downloadInfoIt);
 
 	// update progress
-	sendSocketMessage(workerPipe, vector< string >{ "progress", uri, "done", result });
+	workerQueue.push({ "progress", uri, "done", result });
 
 	// schedule next download if any
-	sendSocketMessage(workerPipe, vector< string >{ "pop-download" });
+	workerQueue.push({ "pop-download" });
 }
 
-void ManagerImpl::killPerformerBecauseOfWrongSize(Pipe& workerPipe,
+void ManagerImpl::killPerformerBecauseOfWrongSize(MessageQueue& workerQueue,
 		const string& uri, const string& actionName, const string& errorString)
 {
 	// so, this download don't make sense
 	auto downloadInfoIt = activeDownloads.find(uri);
 	if (downloadInfoIt == activeDownloads.end())
 	{
-		fatal2("internal error: download manager: received '%s' submessage for unexistent download, uri '%s'",
+		fatal2i("download manager: received '%s' submessage for unexistent download, uri '%s'",
 				actionName, uri);
 	}
 	ActiveDownloadInfo& downloadInfo = downloadInfoIt->second;
 	// rest in peace, young process
 	if (kill(downloadInfo.performerPid, SIGTERM) == -1)
 	{
-		fatal2e("unable to kill process %u", downloadInfo.performerPid);
+		fatal2e(__("unable to kill the process %u"), downloadInfo.performerPid);
 	}
 	// process it as failed
-	sendSocketMessage(workerPipe, vector< string >{ "done", uri, errorString });
+	workerQueue.push({ "done", uri, errorString });
 
 	const string& path = downloadInfo.targetPath;
 	if (unlink(path.c_str()) == -1)
 	{
-		warn2e("unable to delete file '%s'", path);
+		warn2e(__("unable to remove the file '%s'"), path);
 	}
 }
 
-void ManagerImpl::processProgressMessage(Pipe& workerPipe, const vector< string >& params)
+void ManagerImpl::processProgressMessage(MessageQueue& workerQueue, const vector< string >& params)
 {
 	if (params.size() < 2) // uri, action name
 	{
-		fatal2("internal error: download manager: wrong parameter count for 'progress' message");
+		fatal2i("download manager: wrong parameter count for 'progress' message");
 	}
 
 	const string& uri = params[0];
@@ -530,7 +529,7 @@ void ManagerImpl::processProgressMessage(Pipe& workerPipe, const vector< string
 		// now compare them strictly
 		if (params.size() != 3)
 		{
-			fatal2("internal error: download manager: wrong parameter count for 'progress' message, 'expected-size' submessage");
+			fatal2i("download manager: wrong parameter count for 'progress' message, 'expected-size' submessage");
 		}
 
 		auto expectedSize = lexical_cast< size_t >(params[2]);
@@ -538,7 +537,7 @@ void ManagerImpl::processProgressMessage(Pipe& workerPipe, const vector< string
 		{
 			auto errorString = format2(__("invalid expected size: expected '%zu', got '%zu'"),
 					downloadSizeIt->second, expectedSize);
-			killPerformerBecauseOfWrongSize(workerPipe, uri, actionName, errorString);
+			killPerformerBecauseOfWrongSize(workerQueue, uri, actionName, errorString);
 		}
 	}
 	else
@@ -548,14 +547,14 @@ void ManagerImpl::processProgressMessage(Pipe& workerPipe, const vector< string
 			// checking for overflows
 			if (params.size() != 4)
 			{
-				fatal2("internal error: download manager: wrong parameter count for 'progress' message, 'downloading' submessage");
+				fatal2i("download manager: wrong parameter count for 'progress' message, 'downloading' submessage");
 			}
 			auto currentSize = lexical_cast< size_t >(params[2]);
 			if (currentSize > downloadSizeIt->second)
 			{
 				auto errorString = format2(__("downloaded more than expected: expected '%zu', downloaded '%zu'"),
 						downloadSizeIt->second, currentSize);
-				killPerformerBecauseOfWrongSize(workerPipe, uri, actionName, errorString);
+				killPerformerBecauseOfWrongSize(workerQueue, uri, actionName, errorString);
 				return;
 			}
 		}
@@ -564,11 +563,11 @@ void ManagerImpl::processProgressMessage(Pipe& workerPipe, const vector< string
 	}
 }
 
-void ManagerImpl::proceedDownload(Pipe& workerPipe, const vector< string >& params, bool debugging)
+void ManagerImpl::proceedDownload(MessageQueue& workerQueue, const vector< string >& params, bool debugging)
 {
 	if (params.size() != 3) // uri, targetPath, waiterSocket
 	{
-		fatal2("internal error: download manager: wrong parameter count for 'progress' message");
+		fatal2i("download manager: wrong parameter count for 'progress' message");
 	}
 	const string& uri = params[0];
 	if (debugging)
@@ -588,7 +587,7 @@ void ManagerImpl::proceedDownload(Pipe& workerPipe, const vector< string >& para
 			// and immediately process it
 			finishPendingDownload(insertIt, result, debugging);
 
-			sendSocketMessage(workerPipe, vector< string >{ "pop-download" });
+			workerQueue.push({ "pop-download" });
 			return;
 		}
 		else if (activeDownloads.count(uri))
@@ -598,7 +597,7 @@ void ManagerImpl::proceedDownload(Pipe& workerPipe, const vector< string >& para
 				debug2("pushed '%s' to pending queue", uri);
 			}
 			pendingDuplicates.insert(make_pair(uri, waiterSocket));
-			sendSocketMessage(workerPipe, vector< string >{ "pop-download" });
+			workerQueue.push({ "pop-download" });
 			return;
 		}
 		else if (activeDownloads.size() >= (size_t)maxSimultaneousDownloadsAllowed)
@@ -637,7 +636,7 @@ void ManagerImpl::startNewDownload(const string& uri, const string& targetPath,
 	auto downloadPid = fork();
 	if (downloadPid == -1)
 	{
-		fatal2e("unable to create performer process: fork failed");
+		fatal2e(__("unable to create a performer process: fork() failed"));
 	}
 	downloadInfo.performerPid = downloadPid;
 
@@ -671,9 +670,17 @@ void ManagerImpl::startNewDownload(const string& uri, const string& targetPath,
 	}
 }
 
-int ManagerImpl::pollAllSockets(const vector< int >& persistentSockets,
-		set< int >& clientSockets, bool exitFlag, bool debugging)
+InputMessage ManagerImpl::pollAllInput(MessageQueue& workerQueue,
+		const vector< int >& persistentSockets, set< int >& clientSockets,
+		bool exitFlag, bool debugging)
 {
+	if (!workerQueue.empty())
+	{
+		auto message = workerQueue.front();
+		workerQueue.pop();
+		return { INT_MAX, std::move(message) };
+	}
+
 	auto newInputPollFd = [](int sock) -> pollfd
 	{
 		pollfd pollFd;
@@ -710,7 +717,7 @@ int ManagerImpl::pollAllSockets(const vector< int >& persistentSockets,
 		}
 		else
 		{
-			fatal2e("unable to poll worker loop sockets");
+			fatal2e(__("unable to poll worker loop sockets"));
 		}
 	}
 
@@ -728,7 +735,7 @@ int ManagerImpl::pollAllSockets(const vector< int >& persistentSockets,
 			sock = accept(sock, NULL, NULL);
 			if (sock == -1)
 			{
-				fatal2e("unable to accept new socket connection");
+				fatal2e(__("unable to accept new socket connection"));
 			}
 			if (debugging)
 			{
@@ -737,10 +744,10 @@ int ManagerImpl::pollAllSockets(const vector< int >& persistentSockets,
 			clientSockets.insert(sock);
 		}
 
-		return sock;
+		return { sock, receiveSocketMessage(sock) };
 	}
 
-	return 0; // exitFlag is set, no more messages to read
+	return { 0, {} }; // exitFlag is set, no more messages to read
 }
 
 void doNothing(int)
@@ -753,12 +760,12 @@ void makeSyscallsRestartable()
 	action.sa_handler = doNothing;
 	if (sigemptyset(&action.sa_mask) == -1)
 	{
-		fatal2e("sigemptyset failed");
+		fatal2e(__("%s() failed"), "sigemptyset");
 	}
 	action.sa_flags = SA_RESTART;
 	if (sigaction(SIGCHLD, &action, NULL) == -1)
 	{
-		fatal2e("download worker: making system calls restartable: sigaction failed");
+		fatal2e(__("%s() failed"), "sigaction");
 	}
 }
 
@@ -771,7 +778,6 @@ void ManagerImpl::worker()
 	}
 
 	parentPipe->useAsReader();
-	Pipe workerPipe("worker's own");
 
 	bool exitFlag = false;
 
@@ -779,16 +785,19 @@ void ManagerImpl::worker()
 	enablePingTimer();
 
 	const vector< int > persistentSockets = {
-			workerPipe.getReaderFd(), pingPipe.getReaderFd(), parentPipe->getReaderFd(), serverSocket
+			pingPipe.getReaderFd(), parentPipe->getReaderFd(), serverSocket
 	};
 	set< int > clientSockets;
 
+	MessageQueue workerQueue;
+
 	// while caller may set exit flag, we should continue processing as long as
 	// something is pending in internal queue
-	int sock;
-	while ((sock = pollAllSockets(persistentSockets, clientSockets, exitFlag, debugging)))
+	InputMessage inputMessage;
+	while (inputMessage = pollAllInput(workerQueue, persistentSockets, clientSockets, exitFlag, debugging), inputMessage.sock)
 	{
-		auto params = receiveSocketMessage(sock);
+		auto sock = inputMessage.sock;
+		auto& params = inputMessage.message;
 		auto command = params[0];
 		params.erase(params.begin());
 
@@ -824,7 +833,7 @@ void ManagerImpl::worker()
 					//
 					// call processPreliminaryResult() immediately to remove sock from
 					// the list of polled sockets
-					processPreliminaryResult(workerPipe, vector< string > {
+					processPreliminaryResult(workerQueue, vector< string > {
 							activeDownloadIt->first, "download method exited unexpectedly" }, debugging);
 					isPerformerSocket = true;
 					break;
@@ -836,7 +845,7 @@ void ManagerImpl::worker()
 				clientSockets.erase(sock); // if it is a client socket
 				if (close(sock) == -1)
 				{
-					fatal2e("unable to close socket");
+					fatal2e(__("unable to close the client socket"));
 				}
 			}
 		}
@@ -845,21 +854,20 @@ void ManagerImpl::worker()
 			// new query appeared
 			if (params.size() != 2) // uri, target path
 			{
-				fatal2("internal error: download manager: wrong parameter count for 'download' message");
+				fatal2i("download manager: wrong parameter count for 'download' message");
 			}
 			const string& uri = params[0];
 			if (debugging)
 			{
 				debug2("download request: '%s'", uri);
 			}
-			sendSocketMessage(workerPipe, vector< string > {
-					"proceed-download", uri, params[1], lexical_cast< string >(sock) });
+			workerQueue.push({ "proceed-download", uri, params[1], lexical_cast< string >(sock) });
 		}
 		else if (command == "set-download-size")
 		{
 			if (params.size() != 2) // uri, size
 			{
-				fatal2("internal error: download manager: wrong parameter count for 'set-download-size' message");
+				fatal2i("download manager: wrong parameter count for 'set-download-size' message");
 			}
 			const string& uri = params[0];
 			const size_t size = lexical_cast< size_t >(params[1]);
@@ -868,16 +876,16 @@ void ManagerImpl::worker()
 		else if (command == "done")
 		{
 			// some query finished, we have preliminary result for it
-			processPreliminaryResult(workerPipe, params, debugging);
+			processPreliminaryResult(workerQueue, params, debugging);
 		}
 		else if (command == "done-ack")
 		{
 			// this is final ACK from download with final result
-			processFinalResult(workerPipe, params, debugging);
+			processFinalResult(workerQueue, params, debugging);
 		}
 		else if (command == "progress")
 		{
-			processProgressMessage(workerPipe, params);
+			processProgressMessage(workerQueue, params);
 		}
 		else if (command == "ping")
 		{
@@ -901,7 +909,7 @@ void ManagerImpl::worker()
 					{
 						goto do_poll;
 					}
-					fatal2e("download worker: polling waiter socket failed");
+					fatal2e(__("download worker: polling the waiter socket failed"));
 				}
 				if (!pollResult)
 				{
@@ -921,7 +929,7 @@ void ManagerImpl::worker()
 				{
 					debug2("enqueue '%s' from hold", next.uri);
 				}
-				sendSocketMessage(workerPipe, vector< string >{ "proceed-download",
+				workerQueue.push({ "proceed-download",
 						next.uri, next.targetPath, lexical_cast< string >(next.waiterSocket) });
 			}
 		}
@@ -929,7 +937,7 @@ void ManagerImpl::worker()
 		{
 			if (params.size() != 2)
 			{
-				fatal2("internal error: download manager: wrong parameter count for 'set-long-alias' message");
+				fatal2i("download manager: wrong parameter count for 'set-long-alias' message");
 			}
 			progress->setLongAliasForUri(params[0], params[1]);
 		}
@@ -937,17 +945,17 @@ void ManagerImpl::worker()
 		{
 			if (params.size() != 2)
 			{
-				fatal2("internal error: download manager: wrong parameter count for 'set-short-alias' message");
+				fatal2i("download manager: wrong parameter count for 'set-short-alias' message");
 			}
 			progress->setShortAliasForUri(params[0], params[1]);
 		}
 		else if (command == "proceed-download")
 		{
-			proceedDownload(workerPipe, params, debugging);
+			proceedDownload(workerQueue, params, debugging);
 		}
 		else
 		{
-			fatal2("internal error: download manager: invalid worker command '%s'", command);
+			fatal2i("download manager: invalid worker command '%s'", command);
 		}
 	}
 	disablePingTimer();
@@ -980,11 +988,11 @@ map< string, InnerDownloadElement > ManagerImpl::convertEntitiesToDownloads(
 		const string& targetPath = entityIt->targetPath;
 		if (targetPath.empty())
 		{
-			fatal2("passed a download entity with empty target path");
+			fatal2(__("passed a download entity with an empty target path"));
 		}
 		if (result.count(targetPath))
 		{
-			fatal2("passed distinct download entities with the same target path '%s'", targetPath);
+			fatal2(__("passed distinct download entities with the same target path '%s'"), targetPath);
 		}
 		InnerDownloadElement& element = result[targetPath];
 
@@ -1026,12 +1034,12 @@ static void checkSocketForTimeout(int sock)
 		}
 		else
 		{
-			fatal2e("download client: polling client socket failed");
+			fatal2e(__("download client: polling the client socket failed"));
 		}
 	}
 	else if (!pollResult)
 	{
-		fatal2("download client: download server socket is timed out");
+		fatal2(__("download client: the download server socket timed out"));
 	}
 }
 
@@ -1059,11 +1067,11 @@ string ManagerImpl::download(const vector< Manager::DownloadEntity >& entities)
 	auto sock = socket(AF_UNIX, SOCK_STREAM, 0);
 	if (sock == -1)
 	{
-		fatal2e("unable to open client socket");
+		fatal2e(__("unable to open a client socket"));
 	}
 	if (connect(sock, (sockaddr*)&serverSocketAddress, sizeof(sockaddr_un)) == -1)
 	{
-		fatal2e("unable to connect to server socket");
+		fatal2e(__("unable to connect to the server socket"));
 	}
 
 	auto scheduleDownload = [&sock, &downloads, &waitedUriToTargetPath](const string& targetPath)
@@ -1111,14 +1119,14 @@ string ManagerImpl::download(const vector< Manager::DownloadEntity >& entities)
 		}
 		if (params.size() != 3)
 		{
-			fatal2("internal error: download client: wrong parameter count for download result message");
+			fatal2i("download client: wrong parameter count for download result message");
 		}
 		const string& uri = params[0];
 
 		auto waitedUriIt = waitedUriToTargetPath.find(uri);
 		if (waitedUriIt == waitedUriToTargetPath.end())
 		{
-			fatal2("internal error: download client: received unknown uri '%s'", uri);
+			fatal2i("download client: received unknown uri '%s'", uri);
 		}
 
 		const string targetPath = waitedUriIt->second;
@@ -1139,11 +1147,11 @@ string ManagerImpl::download(const vector< Manager::DownloadEntity >& entities)
 			}
 			catch (std::exception& e)
 			{
-				errorString = format2(__("postaction raised an exception '%s'"), e.what());
+				errorString = format2(__("the postprocessing action raised an exception '%s'"), e.what());
 			}
 			catch (...)
 			{
-				errorString = __("postaction raised an exception");
+				errorString = __("the postprocessing action raised an exception");
 			}
 		}
 
@@ -1172,7 +1180,7 @@ string ManagerImpl::download(const vector< Manager::DownloadEntity >& entities)
 
 	if (close(sock) == -1)
 	{
-		fatal2e("unable to close client socket");
+		fatal2e(__("unable to close the client socket"));
 	}
 
 	return result;
