@@ -33,7 +33,7 @@ static int __guarded_fileno(FILE* handle, const string& path)
 	int fd = fileno(handle);
 	if (fd == -1)
 	{
-		fatal2e("fileno on file '%s' failed", path);
+		fatal2e(__("%s() failed: '%s'"), "fileno", path);
 	}
 	return fd;
 }
@@ -61,7 +61,7 @@ FileImpl::FileImpl(const string& path_, const char* mode, string& openError)
 	{
 		if (strlen(mode) != 2)
 		{
-			fatal2("pipe specification mode should be exact 2 characters");
+			fatal2(__("pipe specification mode should be exactly 2 characters"));
 		}
 		isPipe = true;
 		handle = popen(path.c_str(), mode+1);
@@ -105,18 +105,18 @@ FileImpl::~FileImpl()
 			auto pcloseResult = pclose(handle);
 			if (pcloseResult == -1)
 			{
-				fatal2e("unable to close pipe '%s'", path);
+				fatal2e(__("unable to close the pipe '%s'"), path);
 			}
 			else if (pcloseResult)
 			{
-				fatal2("pipe '%s' execution failed: %s", path, getWaitStatusDescription(pcloseResult));
+				fatal2(__("execution of the pipe '%s' failed: %s"), path, getWaitStatusDescription(pcloseResult));
 			}
 		}
 		else
 		{
 			if (fclose(handle))
 			{
-				fatal2e("unable to close file '%s'", path);
+				fatal2e(__("unable to close the file '%s'"), path);
 			}
 		}
 	}
@@ -128,7 +128,7 @@ void FileImpl::assertFileOpened() const
 	if (!handle)
 	{
 		// file was not properly opened
-		fatal2("internal error: file '%s' was not properly opened", path);
+		fatal2i("file '%s' was not properly opened", path);
 	}
 }
 
@@ -145,7 +145,7 @@ size_t FileImpl::getLineImpl()
 		if (!feof(handle))
 		{
 			// real error
-			fatal2e("unable to read from file '%s'", path);
+			fatal2e(__("unable to read from the file '%s'"), path);
 		}
 
 		// ok, end of file
@@ -194,7 +194,7 @@ File& File::getBlock(char* buffer, size_t& size)
 		if (!feof(__impl->handle))
 		{
 			// real error
-			fatal2e("unable to read from file '%s'", __impl->path);
+			fatal2e(__("unable to read from the file '%s'"), __impl->path);
 		}
 	}
 	return *this;
@@ -244,13 +244,13 @@ void File::seek(size_t newPosition)
 {
 	if (__impl->isPipe)
 	{
-		fatal2("an attempt to seek on pipe '%s'", __impl->path);
+		fatal2(__("an attempt to seek on the pipe '%s'"), __impl->path);
 	}
 	else
 	{
 		if (fseek(__impl->handle, newPosition, SEEK_SET) == -1)
 		{
-			fatal2e("unable to seek on file '%s'", __impl->path);
+			fatal2e(__("unable to seek on the file '%s'"), __impl->path);
 		}
 	}
 }
@@ -259,14 +259,14 @@ size_t File::tell() const
 {
 	if (__impl->isPipe)
 	{
-		fatal2("an attempt to tell position on pipe '%s'", __impl->path);
+		fatal2(__("an attempt to tell a position on the pipe '%s'"), __impl->path);
 	}
 	else
 	{
 		long result = ftell(__impl->handle);
 		if (result == -1)
 		{
-			fatal2e("unable to tell position on file '%s'", __impl->path);
+			fatal2e(__("unable to tell a position on the file '%s'"), __impl->path);
 		}
 		else
 		{
@@ -283,8 +283,8 @@ void File::lock(int flags)
 	// TODO/API break/: provide only lock(void) and unlock(void) methods, consider using fcntl
 	if (flock(fd, flags) == -1)
 	{
-		const char* actionName = (flags & LOCK_UN) ? "release" : "obtain";
-		fatal2e("unable to %s lock on file '%s'", actionName, __impl->path);
+		auto actionName = (flags & LOCK_UN) ? __("release") : __("obtain");
+		fatal2e(__("unable to %s a lock on the file '%s'"), actionName, __impl->path);
 	}
 }
 
@@ -293,7 +293,7 @@ void File::put(const char* data, size_t size)
 	__impl->assertFileOpened();
 	if (fwrite(data, size, 1, __impl->handle) != 1)
 	{
-		fatal2e("unable to write to file '%s'", __impl->path);
+		fatal2e(__("unable to write to the file '%s'"), __impl->path);
 	}
 }
 
@@ -319,7 +319,7 @@ void File::unbufferedPut(const char* data, size_t size)
 			}
 			else
 			{
-				fatal2e("unable to write to file '%s'", __impl->path);
+				fatal2e(__("unable to write to the file '%s'"), __impl->path);
 			}
 		}
 		currentOffset += writeResult;
