@@ -46,6 +46,8 @@ ScoreManager::ScoreManager(const Config& config, const shared_ptr< const Cache >
 				leafOption = "removal"; break;
 			case ScoreChange::SubScore::RemovalOfEssential:
 				leafOption = "removal-of-essential"; break;
+			case ScoreChange::SubScore::RemovalOfAuto:
+				leafOption = "removal-of-autoinstalled"; break;
 			case ScoreChange::SubScore::Upgrade:
 				leafOption = "upgrade"; break;
 			case ScoreChange::SubScore::Downgrade:
@@ -59,7 +61,7 @@ ScoreManager::ScoreManager(const Config& config, const shared_ptr< const Cache >
 			case ScoreChange::SubScore::FailedSync:
 				leafOption = "failed-synchronization"; break;
 			default:
-				fatal2("internal error: missing score multiplier for the score '%zu'", i);
+				fatal2i("missing score multiplier for the score '%zu'", i);
 		}
 
 		__subscore_multipliers[i] = config.getInteger(
@@ -97,6 +99,10 @@ ScoreChange ScoreManager::getVersionScoreChange(const shared_ptr< const BinaryVe
 		{
 			scoreChange.__subscores[ScoreChange::SubScore::RemovalOfEssential] = 1;
 		}
+		if (__cache->isAutomaticallyInstalled(originalVersion->packageName))
+		{
+			scoreChange.__subscores[ScoreChange::SubScore::RemovalOfAuto] = 1;
+		}
 	}
 	else
 	{
@@ -184,6 +190,8 @@ string ScoreChange::__to_string() const
 					result << 'r'; break;
 				case SubScore::RemovalOfEssential:
 					result << "re"; break;
+				case SubScore::RemovalOfAuto:
+					result << "ra"; break;
 				case SubScore::Upgrade:
 					result << 'u'; break;
 				case SubScore::Downgrade:
