@@ -28,7 +28,7 @@ namespace internal {
 
 WorkerBase::WorkerBase()
 {
-	fatal2("internal error: WorkerBase::WorkerBase shouldn't be ever called");
+	fatal2i("WorkerBase::WorkerBase shouldn't be ever called");
 }
 
 WorkerBase::WorkerBase(const shared_ptr< const Config >& config, const shared_ptr< const Cache >& cache)
@@ -88,13 +88,13 @@ void WorkerBase::_run_external_command(Logger::Subsystem subsystem,
 			auto result = ::system(command.c_str());
 			if (result == -1)
 			{
-				_logger->loggedFatal(subsystem, level,
-						format2e("unable to launch command '%s'", command));
+				_logger->loggedFatal2(subsystem, level,
+						format2e, "unable to launch the command '%s'", command);
 			}
 			else if (result)
 			{
-				_logger->loggedFatal(subsystem, level,
-						format2("command '%s' execution failed: %s", command, getWaitStatusDescription(result)));
+				_logger->loggedFatal2(subsystem, level,
+						format2, "the command '%s' failed: %s", command, getWaitStatusDescription(result));
 			}
 		}
 		else try
@@ -104,15 +104,15 @@ void WorkerBase::_run_external_command(Logger::Subsystem subsystem,
 			File pipeFile(command, "pw", errorString);
 			if (!errorString.empty())
 			{
-				_logger->loggedFatal(subsystem, level,
-						format2("unable to launch a pipe to the command '%s': %s", command, errorString));
+				_logger->loggedFatal2(subsystem, level,
+						format2, "unable to open the pipe '%s': %s", command, errorString);
 			}
 
 			pipeFile.put(commandInput);
 		}
 		catch (...)
 		{
-			_logger->loggedFatal(subsystem, level, id + " failed");
+			_logger->loggedFatal2(subsystem, level, format2, "%s failed", id);
 		}
 	}
 }
