@@ -47,14 +47,14 @@ void SnapshotsWorker::__delete_temporary(const string& directory, bool warnOnly)
 	}
 	catch (Exception&)
 	{
-		auto message = format2("unable to delete partial snapshot directory '%s'", directory);
 		if (warnOnly)
 		{
-			warn2("%s", message);
+			warn2(__("unable to remove the partial snapshot directory '%s'"), directory);
 		}
 		else
 		{
-			_logger->loggedFatal(Logger::Subsystem::Snapshots, 2, message);
+			_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+					format2, "unable to remove the partial snapshot directory '%s'", directory);
 		}
 	}
 }
@@ -74,8 +74,8 @@ void createTextFile(const string& path, const vector< string >& lines,
 		File file(path, "w", openError);
 		if (!openError.empty())
 		{
-			logger->loggedFatal(Logger::Subsystem::Snapshots, 3,
-					format2("unable to open file '%s' for writing: %s", path, openError));
+			logger->loggedFatal2(Logger::Subsystem::Snapshots, 3,
+					format2, "unable to open the file '%s': %s", path, openError);
 		}
 
 		FORIT(lineIt, lines)
@@ -101,14 +101,14 @@ void SnapshotsWorker::__do_repacks(const vector< string >& installedPackageNames
 			auto package = _cache->getBinaryPackage(packageName);
 			if (!package)
 			{
-				_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-						format2("internal error: no binary package '%s'", packageName));
+				_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+						format2, "internal error: no binary package '%s'", packageName);
 			}
 			auto version = package->getInstalledVersion();
 			if (!version)
 			{
-				_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-						format2("internal error: no installed version for the installed package '%s'", packageName));
+				_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+						format2, "internal error: no installed version for the installed package '%s'", packageName);
 			}
 			const string& architecture = version->architecture;
 
@@ -128,26 +128,25 @@ void SnapshotsWorker::__do_repacks(const vector< string >& installedPackageNames
 				auto files = fs::glob(packageName + "_*.deb");
 				if (files.size() != 1)
 				{
-					_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-							format2("dpkg-repack produced either no or more than one Debian archive for the package '%s'",
-							packageName));
+					_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+							format2, "dpkg-repack produced either no or more than one Debian archive for the package '%s'",
+							packageName);
 				}
 				const string& badFilename = files[0];
 				auto goodFilename = format2("%s_%s_%s.deb", packageName,
 						version->versionString, architecture);
 
-				auto moveError = fs::move(badFilename, goodFilename);
-				if (!moveError.empty())
+				if (!fs::move(badFilename, goodFilename))
 				{
-					_logger->loggedFatal(Logger::Subsystem::Snapshots, 3,
-							format2("unable to move '%s' to '%s': %s", badFilename, goodFilename, moveError));
+					_logger->loggedFatal2(Logger::Subsystem::Snapshots, 3,
+							format2e, "unable to rename '%s' to '%s'", badFilename, goodFilename);
 				}
 			}
 		}
 		catch (...)
 		{
-			_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-					format2("failed to repack the package '%s'", packageName));
+			_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+					format2, "failed to repack the package '%s'", packageName);
 		}
 	}
 }
@@ -182,7 +181,7 @@ void SnapshotsWorker::__create_release_file(const string& temporarySnapshotDirec
 		char timeBuf[128];
 		if (!strftime(timeBuf, sizeof(timeBuf), "%a, %d %b %Y %H:%M:%S UTC", gmtime_r(&unixTime, &brokenDownTime)))
 		{
-			_logger->loggedFatal(Logger::Subsystem::Snapshots, 2, format2e("strftime failed"));
+			_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2, format2e, "%s() failed", "strftime");
 		}
 		LL(string("Date: ") + timeBuf);
 
@@ -217,18 +216,18 @@ void checkSnapshotName(const Snapshots& snapshots, const string& name)
 {
 	if (name.empty())
 	{
-		fatal2("the system snapshot name cannot be empty");
+		fatal2(__("the system snapshot name cannot be empty"));
 	}
 	if (name[0] == '.')
 	{
-		fatal2("the system snapshot name '%s' cannot start with a '.'", name);
+		fatal2(__("the system snapshot name '%s' cannot start with a '.'"), name);
 	}
 
 	{
 		auto existingNames = snapshots.getSnapshotNames();
 		if (std::find(existingNames.begin(), existingNames.end(), name) != existingNames.end())
 		{
-			fatal2("the system snapshot named '%s' already exists", name);
+			fatal2(__("the system snapshot named '%s' already exists"), name);
 		}
 	}
 }
@@ -238,11 +237,11 @@ void checkSnapshotSavingTools()
 	// ensuring needed tools is available
 	if (::system("which dpkg-repack >/dev/null 2>/dev/null"))
 	{
-		fatal2("the 'dpkg-repack' binary is not available, install the package 'dpkg-repack'");
+		fatal2(__("the 'dpkg-repack' binary is not available, install the package 'dpkg-repack'"));
 	}
 	if (::system("which dpkg-scanpackages >/dev/null 2>/dev/null"))
 	{
-		fatal2("the 'dpkg-scanpackages' binary is not available, install the package 'dpkg-dev'");
+		fatal2(__("the 'dpkg-scanpackages' binary is not available, install the package 'dpkg-dev'"));
 	}
 
 }
@@ -268,8 +267,8 @@ void SnapshotsWorker::saveSnapshot(const Snapshots& snapshots, const string& nam
 		{
 			if (mkdir(snapshotsDirectory.c_str(), 0755) == -1)
 			{
-				_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-						format2e("unable to create the snapshots directory '%s'", snapshotsDirectory));
+				_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+						format2e, "unable to create the snapshots directory '%s'", snapshotsDirectory);
 			}
 		}
 		if (fs::dirExists(temporarySnapshotDirectory))
@@ -279,8 +278,8 @@ void SnapshotsWorker::saveSnapshot(const Snapshots& snapshots, const string& nam
 		}
 		if (mkdir(temporarySnapshotDirectory.c_str(), 0755) == -1)
 		{
-			_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-					format2e("unable to create a temporary snapshot directory '%s'", temporarySnapshotDirectory));
+			_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+					format2e, "unable to create a temporary snapshot directory '%s'", temporarySnapshotDirectory);
 		}
 	}
 
@@ -308,16 +307,16 @@ void SnapshotsWorker::saveSnapshot(const Snapshots& snapshots, const string& nam
 		auto currentDirectoryFd = open(".", O_RDONLY);
 		if (currentDirectoryFd == -1)
 		{
-			_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-					format2e("unable to open the current directory"));
+			_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+					format2e, "unable to open the current directory");
 		}
 
 		if (!simulating)
 		{
 			if (chdir(temporarySnapshotDirectory.c_str()) == -1)
 			{
-				_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-						format2e("unable to set current directory to '%s'", temporarySnapshotDirectory));
+				_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+						format2e, "unable to set the current directory to '%s'", temporarySnapshotDirectory);
 			}
 		}
 
@@ -336,17 +335,16 @@ void SnapshotsWorker::saveSnapshot(const Snapshots& snapshots, const string& nam
 		{
 			if (fchdir(currentDirectoryFd) == -1)
 			{
-				_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-						format2e("unable to return to previous working directory"));
+				_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+						format2e, "unable to return to a previous working directory");
 			}
 
 			// all done, do final move
-			auto moveError = fs::move(temporarySnapshotDirectory, snapshotDirectory);
-			if (!moveError.empty())
+			if (!fs::move(temporarySnapshotDirectory, snapshotDirectory))
 			{
-				_logger->loggedFatal(Logger::Subsystem::Snapshots, 2,
-						format2("unable to move directory '%s' to '%s': %s",
-						temporarySnapshotDirectory, snapshotDirectory, moveError));
+				_logger->loggedFatal2(Logger::Subsystem::Snapshots, 2,
+						format2e, "unable to rename '%s' to '%s'",
+						temporarySnapshotDirectory, snapshotDirectory);
 			}
 		}
 	}
@@ -355,22 +353,13 @@ void SnapshotsWorker::saveSnapshot(const Snapshots& snapshots, const string& nam
 		// deleting partially constructed snapshot (try)
 		if (chdir(snapshotsDirectory.c_str()) == -1)
 		{
-			warn2e("unable to set current directory to '%s'", snapshotsDirectory);
+			warn2e(__("unable to set the current directory to '%s'"), snapshotsDirectory);
 		}
 
-		try
-		{
-			_run_external_command(Logger::Subsystem::Snapshots,
-					string("rm -r " + temporarySnapshotDirectory));
-		}
-		catch (...)
-		{
-			warn2("unable to delete partial snapshot directory '%s'",
-					temporarySnapshotDirectory);
-		}
+		__delete_temporary(temporarySnapshotDirectory, true);
 
-		_logger->loggedFatal(Logger::Subsystem::Snapshots, 1,
-				format2("error constructing system snapshot named '%s'", name));
+		_logger->loggedFatal2(Logger::Subsystem::Snapshots, 1,
+				format2, "unable to construct the system snapshot '%s'", name);
 	}
 }
 
@@ -381,12 +370,12 @@ void SnapshotsWorker::renameSnapshot(const Snapshots& snapshots,
 	if (std::find(snapshotNames.begin(), snapshotNames.end(), previousName)
 			== snapshotNames.end())
 	{
-		fatal2("unable to find snapshot named '%s'", previousName);
+		fatal2(__("unable to find a snapshot named '%s'"), previousName);
 	}
 	if (std::find(snapshotNames.begin(), snapshotNames.end(), newName)
 			!= snapshotNames.end())
 	{
-		fatal2("the snapshot named '%s' already exists", newName);
+		fatal2(__("the snapshot '%s' already exists"), newName);
 	}
 
 	auto previousSnapshotDirectory = snapshots.getSnapshotDirectory(previousName);
@@ -402,7 +391,7 @@ void checkLooksLikeSnapshot(const string& directory)
 {
 	if (!fs::fileExists(directory + '/' + Snapshots::installedPackageNamesFilename))
 	{
-		fatal2("'%s' is not a valid snapshot", directory);
+		fatal2(__("'%s' is not a valid snapshot"), directory);
 	}
 }
 
@@ -412,7 +401,7 @@ void SnapshotsWorker::removeSnapshot(const Snapshots& snapshots, const string& n
 	if (std::find(snapshotNames.begin(), snapshotNames.end(), name)
 			== snapshotNames.end())
 	{
-		fatal2("unable to find snapshot named '%s'", name);
+		fatal2(__("unable to find a snapshot named '%s'"), name);
 	}
 
 	auto snapshotDirectory = snapshots.getSnapshotDirectory(name);
